==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/VradiAdminBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import org.sharengo.wikitty.BusinessEntityBean;

public class VradiAdminBean extends com.jurismarches.vradi.entities.VradiUserBean implements VradiAdmin, VradiUser {

    private static final long serialVersionUID = 780597782L;

    public VradiAdminBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String VradiUser$name;

     public String VradiUser$password;

     public String VradiUser$email;

 
    public void setName(String value) {
        Object oldValue = VradiUser$name; 
        this.VradiUser$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return VradiUser$name;
    }


    public void setPassword(String value) {
        Object oldValue = VradiUser$password; 
        this.VradiUser$password = value;
        propertyChange.firePropertyChange("password", oldValue, value);
    }

    public String getPassword() {
        return VradiUser$password;
    }


    public void setEmail(String value) {
        Object oldValue = VradiUser$email; 
        this.VradiUser$email = value;
        propertyChange.firePropertyChange("email", oldValue, value);
    }

    public String getEmail() {
        return VradiUser$email;
    }


} //VradiAdminBean

==> vradi-entities-0.0.5-sources.jar: com/jurismarches/vradi/entities/VradiAdminBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import org.sharengo.wikitty.BusinessEntityBean;

public class VradiAdminBean extends com.jurismarches.vradi.entities.VradiUserBean implements VradiAdmin, VradiUser {

    private static final long serialVersionUID = 780597782L;

    public VradiAdminBean() {
        super();
    }

    protected transient PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String VradiUser$name;

    public String VradiUser$password;

    public String VradiUser$email;


    public void setName(String value) {
        Object oldValue = VradiUser$name; 
        this.VradiUser$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return VradiUser$name;
    }


    public void setPassword(String value) {
        Object oldValue = VradiUser$password; 
        this.VradiUser$password = value;
        propertyChange.firePropertyChange("password", oldValue, value);
    }

    public String getPassword() {
        return VradiUser$password;
    }


    public void setEmail(String value) {
        Object oldValue = VradiUser$email; 
        this.VradiUser$email = value;
        propertyChange.firePropertyChange("email", oldValue, value);
    }

    public String getEmail() {
        return VradiUser$email;
    }


} //VradiAdminBean
